@@ -20,6 +20,8 @@
 
 import sys, os, shlex, glob,shutil
 
+from SPBasePaths import SHARELIBDATADIR
+
 if len(sys.argv) > 2:
     if sys.argv[1] == '--plainversion':
         from SPVersion import version
@@ -144,7 +146,6 @@ if not os.path.exists(p):
     if os.path.exists(CONTENTDBASE):
         shutil.copy(CONTENTDBASE, p)
     else:
-        from SPBasePaths import SHARELIBDATADIR
         shutil.copy(os.path.join(SHARELIBDATADIR, CONTENTDBASE), p)
                         
 import pygame
@@ -154,10 +155,20 @@ import pygame
 pygame.mixer.pre_init(22050, -16, 2, 2048)
 pygame.init()
 
-
 # this will return the tuple (lang,rtl=bool)
 LANG = utils.set_locale(lang=CMD_Options.lang)
 
+# display a splash for 3 seconds
+start_splash = time.time()
+screen = pygame.display.set_mode((700, 200), pygame.NOFRAME)
+background = pygame.Surface(screen.get_size())
+p = os.path.join(SHARELIBDATADIR, 'SPData/themes/childsplay/cp-btp-splash.png')
+backgroundimage = utils.load_image(p)
+background.blit(backgroundimage, (0, 0))
+screen.blit(background, (0, 0))
+pygame.display.update()
+
+
 if CMD_Options.checklog:
     try:
         import SPlogCheck
@@ -212,10 +223,11 @@ while not abort:
         session_id = result.ID
         session.close()
         # there's no support for other resolutions then 800x600
-        mcgui = SPMainCore.MainCoreGui(resolution=(800,600),\
-                                        options=CMD_Options, dbmaker = dbm,\
-                                        mainscr=mainscreen, error=tellcore_error, \
-                                        session_id=session_id)
+        mcgui = SPMainCore.MainCoreGui(resolution=(800, 600),
+                                        options=CMD_Options, dbmaker = dbm,
+                                        mainscr=mainscreen, error=tellcore_error,
+                                        session_id=session_id, start_splash=start_splash,
+                                       language=LANG)
         mainscreen = mcgui.get_mainscreen()
         mcgui.start()
     except SPMainCore.MainEscapeKeyException:
