@@ -1,7 +1,7 @@
 
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 Stas Zytkiewicz stas.zytkiewicz@gmail.com
+# Copyright (c) 2010 Stas Zytkiewicz stas.zytkiewicz@schoolsplay.org
 #
 #           pong.py
 # This program is free software; you can redistribute it and/or
@@ -21,11 +21,11 @@
 #create logger, logger was setup in SPLogging
 import logging
 # In your Activity class -> 
-# self.logger =  logging.getLogger("schoolsplay.pong.Activity")
+# self.logger =  logging.getLogger("childsplay.pong.Activity")
 # self.logger.error("I don't understand logger")
 # See SP manual for more info 
 
-module_logger = logging.getLogger("schoolsplay.pong")
+module_logger = logging.getLogger("childsplay.pong")
 
 # standard modules you probably need
 import os,sys,random
@@ -33,9 +33,9 @@ import os,sys,random
 import pygame
 from pygame.constants import *
 
-import childsplay_sp.utils as utils
-from childsplay_sp.SPConstants import *
-import childsplay_sp.SPSpriteUtils as SPSpriteUtils
+import utils
+from SPConstants import *
+import SPSpriteUtils
 
 # containers that can be used globally to store stuff
 class Img:
@@ -43,9 +43,7 @@ class Img:
 class Snd:
     pass
 class Misc:
-    """ Container to store all kind of stuff"""
     pass
-    
 # Options used by the game.
 # THESE OPTIONS ARE USED, NO CONFIG FILE EXISTS IN CHILDSPLAY_SP
 # These will be merged with the ones from the rcdic.
@@ -93,7 +91,7 @@ class PcPlayer:
     """The computer player.
     This will control the bat by adding pygame events to the pygame event queue.
     """
-    def __init__(self):
+    def __init__(self, rc_dic):
         """bat must be a Bat class object."""
         self.up,self.down = ord(Misc.bat_l.up),ord(Misc.bat_l.down)
         self.u_up,self.u_down = unicode(Misc.bat_l.up), unicode(Misc.bat_l.down)
@@ -102,11 +100,11 @@ class PcPlayer:
         self.event_dict = {'key':self.up,'unicode':self.u_up}
         self.keystate = KEYUP
         #self.counter = 2# about 0.15 second (clockrate chidsplay 30/sec)
-        self.AIlist = (0,)*(int(Misc.rc_dic['ballspeed'])-1) + (1,)
+        self.AIlist = (0,)*(int(rc_dic['ballspeed'])-1) + (1,)
         Misc.bat_l.init_speed = 6
-        if Misc.rc_dic['computerAI'] == 'hard':
+        if rc_dic['computerAI'] == 'hard':
             self.AIlist = (0,0, 1)
-        elif Misc.rc_dic['computerAI'] == 'impossible':
+        elif rc_dic['computerAI'] == 'impossible':
             self.AIlist = (0,0)
         
     def play(self,events):
@@ -141,9 +139,9 @@ class PcPlayer:
         return events
 
 class ScoreBoard:
-    def __init__(self,end=11,size=48):
+    def __init__(self,rc_dic, end=11,size=48):
         try:
-            s = int(Misc.rc_dic['winpoints'])
+            s = int(rc_dic['winpoints'])
         except (TypeError,KeyError):
             pass
         else: end = s
@@ -189,9 +187,9 @@ class ScoreBoard:
             self.update()
 
 class Goal:
-    def __init__(self,size=(20,300)):
+    def __init__(self,rc_dic, scoreboard, size=(20,300)):
         try:
-            s = int(Misc.rc_dic['goalsize'])
+            s = int(rc_dic['goalsize'])
         except (TypeError,KeyError):
             pass
         else: size = (20,s)
@@ -199,6 +197,7 @@ class Goal:
         self.score = 0
         #self.image.fill((255,255,255))# use to display goals (debugging)
         self.rect = self.image.get_rect()
+        self.scoreboard = scoreboard
     def set_scoreboard(self,side):
         self.side = side#this should be the other side
     def move(self,pos):
@@ -206,14 +205,14 @@ class Goal:
     def scored(self):
         Snd.goal.play()
         self.score += 1
-        Misc.scoreboard.set_score(1,self.side)
+        self.scoreboard.set_score(1,self.side)
     def get_score(self):
         return self.score    
 
 class Ball(SPSpriteUtils.SPSprite):
-    def __init__(self,speed=4):
+    def __init__(self,rc_dic, speed=4):
         try:
-            s = int(Misc.rc_dic['ballspeed'])
+            s = int(rc_dic['ballspeed'])
         except (TypeError,KeyError):
             pass
         else: speed = s
@@ -254,7 +253,7 @@ class Ball(SPSpriteUtils.SPSprite):
         for obj in (Misc.goal_l,Misc.goal_r):
             if self.rect.colliderect(obj.rect):
                 obj.scored()
-                return -1
+                return -2
         collide = self.rect.colliderect(Misc.bat_r.rect) or \
                     self.rect.colliderect(Misc.bat_l.rect)
         if collide:
@@ -262,11 +261,11 @@ class Ball(SPSpriteUtils.SPSprite):
             Snd.pong.play()
 
 class Bat(SPSpriteUtils.SPSprite):
-    def __init__(self,action_keys,size=64,speed=12):
+    def __init__(self,rc_dic, action_keys,size=64,speed=12):
         self.current_key = None#used to fix the "no unicode key in keyup event" pygame bug
         try:
-            s = int(Misc.rc_dic['batspeed'])
-            bs = int(Misc.rc_dic['batsize'])
+            s = int(rc_dic['batspeed'])
+            bs = int(rc_dic['batsize'])
         except (TypeError,KeyError):
             pass
         else: 
@@ -304,9 +303,11 @@ class Bat(SPSpriteUtils.SPSprite):
                         self.speed = self.init_speed
                         self.speed = abs(self.speed)
                         self.current_key = c
+                break
             elif event.type == KEYUP and self.current_key:
                 self.speed = 0
                 self.current_key = None
+                break
         newrect = self.rect.move(0,self.speed)
         if newrect.top > self.top and newrect.bottom < self.bottom:
             self.rect = newrect
@@ -315,34 +316,58 @@ class Activity:
     """  Base class mandatory for any SP activty.
     The activity is started by instancing this class by the core.
     This class must at least provide the following methods.
-    start (self) called by the core before calling loop.
+    start (self) called by the core before calling 'next_level'.
+    post_next_level (self) called once by the core after 'next_level' *and* after the 321 count. 
     next_level (self,level) called by the core when the user changes levels.
     loop (self,events) called 40 times a second by the core and should be your 
                       main eventloop.
-    helptitle (self) must return the title of the game can be localized.
-    help (self) must return a list of strings describing the activty.
-    name (self) must provide the activty name in english, not localized in lowercase.
+    get_helptitle (self) must return the title of the game can be localized.
+    get_help (self) must return a list of strings describing the activty.
+    get_helptip (self) must return a list of strings or an empty list
+    get_name (self) must provide the activty name in english, not localized in lowercase.
+    stop_timer (self) must stop any timers if any.
   """
 
     def __init__(self,SPGoodies):
         """SPGoodies is a class object that SP sets up and will contain references
         to objects, callback methods and observers
         TODO: add more explaination"""
-        self.logger =  logging.getLogger("schoolsplay.pong.Activity")
+        self.logger =  logging.getLogger("childsplay.pong.Activity")
         self.logger.info("Activity started")
         self.SPG = SPGoodies
+        self.scoredisplay = self.SPG.get_scoredisplay()
+        self.theme = self.SPG.get_theme()
         self.screen = self.SPG.get_screen()
+        self.screenclip = self.SPG.get_screenclip()
+        self.blit_pos = self.screenclip.left, self.screenclip.top
+        self.orgscreen = pygame.Surface(self.screenclip.size) # we use this to restore the screen
+        self.orgscreen.blit(self.screen, (0, 0), self.screenclip)
         self.backgr = self.SPG.get_background()
-        Img.org_screen = self.screen.convert()
-        Img.org_backgr = self.backgr.convert()
-        self.my_datadir = os.path.join(self.SPG.get_libdir_path(),'CPData','PongData')
         Img.screen = self.screen
         Img.backgr = self.backgr
+        # The location of the activities Data dir
+        self.my_datadir = os.path.join(self.SPG.get_libdir_path(),'CPData','PongData')
+        # Location of the CPData dir which holds some stuff used by multiple activities
+        self.CPdatadir = os.path.join(self.SPG.get_libdir_path(),'CPData')
+        # Location of the alphabet sounds dir
+        self.absdir = self.SPG.get_absdir_path()# alphabet sounds dir
+        self.rchash = utils.read_rcfile(os.path.join(self.my_datadir, 'c'))
         # You MUST call SPInit BEFORE using any of the SpriteUtils stuff
         # it returns a reference to the special CPGroup
-        Misc.actives = SPSpriteUtils.SPInit(self.screen,self.backgr)
-        Misc.rc_dic = defaults_dict
-        
+        self.actives = SPSpriteUtils.SPInit(self.screen,self.backgr)
+        self.rc_dic = defaults_dict
+        self.SPG.tellcore_disable_menubuttons()
+    
+    def clear_screen(self):
+        self.screen.blit(self.orgscreen,self.blit_pos)
+        self.backgr.blit(self.orgscreen,self.blit_pos)
+        pygame.display.update()
+
+    def refresh_sprites(self):
+        """Mandatory method, called by the core when the screen is used for blitting
+        and the possibility exists that your sprites are affected by it."""
+        self.actives.refresh()
+
     def get_helptitle(self):
         """Mandatory method"""
         return _("Pong")
@@ -353,48 +378,82 @@ class Activity:
     
     def get_help(self):
         """Mandatory methods"""
-        text = [_("The aim of the game:"),
+        text = [_("The aim of this activity:"),
+        " ",
         _("The classic pong game where you must hit a ball with your bat."),
         _("There are three modes to choose from:"),\
         _("Single play - Hit the ball against the wall."),\
         _("Multi player against the computer - Try to defeat the computer."),\
         _("Multi player - Play against another player."),\
         _("In the multiplayer modes, the one who has 11 points wins."),\
-        " ",\
-        _("The game has a configuration file called 'pongrc', located in the .childsplay directory of your homedirectory."),\
-        _("In this file you can set a number of options to change the game play."),\
         " "]
         return text 
-        
+    
     def get_helptip(self):
         """Mandatory method, when no tips available returns an empty list"""
-        text = []
-        return text 
+        return []
         
     def get_helptype(self):
         """Mandatory method, you must set an type"""
         # Possible types are: Memory, Math, Puzzle, Keyboardtraining, Mousetraining
         #                     Language, Alphabet, Fun, Miscellaneous
         return _("Fun")
-
+    
     def get_helplevels(self):
         """Mandatory method, must return a string with the number of levels
         in the follwing format:
-        _("This level has %s levels" % number-of-levels)"""
-        return _("This activity has %s levels") % 1
+        _("This level has %s levels") % number-of-levels"""
+        return _("This activity has %s levels") % 6
+    
+    def pre_level(self,level):
+        """Mandatory method.
+        Return True to call the eventloop after this method is called."""
+        self.logger.debug("pre_level called with: %s" % level)
+        self.pre_level_flag = True
+        Img.screen.fill((0,0,0))
+        pygame.display.update()
+        # Display the three choices of game play.
+        # This will put the menu items in the actives group which then will be updated
+        # in the game loop. When the users picks one the result will be handled by
+        # the restart method.
+        self.choice = None # will be set in loop
+        # FIXME: disabled the pc pclayer as it's not working right.
+        # The bats are not moving smoothly whit the pcplayer.
+        # The same problem exists when playing with two players but it's less annoying 
+        positions = [(130,70),(130,220)]#,(130,370)]
+        images = ('single.jpg','multi_person.jpg')#,'multi_pc.jpg')
+        head = _("Choose the game to play:")
+        s = utils.char2surf(head,32,GREEN, bold=True)
+        pygame.display.update(Img.screen.blit(s,(80,4)))
+        for pos,img,data in map(None,positions,images,('1','2')):
+            img = os.path.join(self.my_datadir,img)
+            obj = SPSpriteUtils.SPButton(utils.load_image(img),pos,data)
+            self.actives.add(obj)
+            obj.display_sprite() 
+        return True
+        
+    def next_level(self,level,dbmapper):
+        """Mandatory method.
+        Return True if there levels left.
+        False when no more levels left."""
+        self.logger.debug("nextlevel called with: %s" % level)
+        # Your top blit position, this depends on the menubar position 
+        if self.blit_pos[1] == 0:
+            y = 10
+        else:
+            y = 110
+        return True
     
     def start(self):
         """Mandatory method."""
-        
-        Img.screen.fill((0,0,0))
-        pygame.display.update()
+        self.SPG.tellcore_set_dice_minimal_level(6)
         fs = 36
-        Misc.scoreboard = ScoreBoard(size=fs)
+        self.scoreboard = ScoreBoard(self.rc_dic, size=fs)
         Img.winner = utils.load_image(os.path.join(self.my_datadir,'winner.jpg'),1)
         Img.loser = utils.load_image(os.path.join(self.my_datadir,'loser.jpg'),1)
         self.skipstart = None# used when the user sets a predefined game play in the config file
-        self.skipssplash = None
-        if Misc.rc_dic['sound'].lower() == 'no':
+        self.skipsplash = None
+        if self.rc_dic['sound'].lower() == 'no':
             Snd.pong = utils.load_sound(os.path.join(self.my_datadir,''))
             Snd.winner = utils.load_sound(os.path.join(self.my_datadir,''))
             Snd.goal = utils.load_sound(os.path.join(self.my_datadir,''))
@@ -407,41 +466,52 @@ class Activity:
         #set kind of game play
         # we only check for multi and multipc, anything else is considerd single play
         # which is the default
-        if Misc.rc_dic['gameplay'] == 'multi':
+        if self.rc_dic['gameplay'] == 'multi':
             self.restart([[None,'2']])
             self.skipstart = 1
-        elif Misc.rc_dic['gameplay'] == 'multipc':
+        elif self.rc_dic['gameplay'] == 'multipc':
             self.restart([[None,'3']])
             self.skipstart = 1
-        
-    def next_level(self,level,dbmapper):
-        """Return True if there levels left.
-        False when no more levels left."""
-        if level == 2:
-            return False
-        return True
-        
+    
     def post_next_level(self):
         """Mandatory method.
-        This is called by the core after 'next_level' *and* after the 321 count.
+        This is called once by the core after 'next_level' *and* after the 321 count.
         You should place stuff in here that run in a seperate thread like sound play."""
         self.SPG.tellcore_enable_dice(False)
-        if not self.skipstart:
-            self._get_choice()
-        if not self.skipssplash:
+        if not self.skipsplash:
             self._splash_controls()
         self.next_exercise()  
+        
+    def get_score(self,timespend):
+        """Mandatory method.
+        @timespend is the time spend inside the level as it's calculated
+        by the core.
+        returns the score value for the past level.
+        return None if no score value is used"""
+        m,s = timespend.split(':')
+        seconds = int(m)*60 + int(s)
+    
+    def stop_timer(self):
+        """You *must* provide a method to stop timers if you use them.
+        The SPC will call this just in case and catch the exception in case 
+        there's no 'stop_timer' method""" 
+        try:
+            self.timer.stop()
+        except:
+            pass
+        self.SPG.tellcore_enable_menubuttons()
     
     def next_exercise(self):
         self.logger.debug("ONEPLAYER: %s PCPLAYER: %s" % (ONEPLAYER,PCPLAYER))
 
         self.PCplayer = None
+        self.pcplayer_wait = 0
         self._draw_field()
-        Misc.scoreboard.update()
-        Misc.goal_r = Goal()
+        self.scoreboard.update()
+        Misc.goal_r = Goal(self.rc_dic, self.scoreboard)
         Misc.goal_r.set_scoreboard('left')
         Misc.goal_r.move((774,100))
-        Misc.goal_l = Goal()
+        Misc.goal_l = Goal(self.rc_dic, self.scoreboard)
         Misc.goal_l.set_scoreboard('right')
         if ONEPLAYER:
             Misc.goal_l.move((-20,100))# move behind the wall
@@ -454,32 +524,32 @@ class Activity:
         
         lspeed,rspeed = 8,8
         try:
-            u = unicode(Misc.rc_dic['right_keyup'])
-            d = unicode(Misc.rc_dic['right_keydown'])
+            u = unicode(self.rc_dic['right_keyup'])
+            d = unicode(self.rc_dic['right_keydown'])
         except (TypeError,KeyError):
             u,d = u'p',u'l'
-        Misc.bat_r = Bat(action_keys=(u,d),speed=rspeed)# to keep a reference to the bat, see class Ball
+        Misc.bat_r = Bat(self.rc_dic, action_keys=(u,d),speed=rspeed)# to keep a reference to the bat, see class Ball
         Misc.bat_r.set_position((768,220))
         try:
-            u = unicode(Misc.rc_dic['left_keyup'])
-            d = unicode(Misc.rc_dic['left_keydown'])
+            u = unicode(self.rc_dic['left_keyup'])
+            d = unicode(self.rc_dic['left_keydown'])
         except (TypeError,KeyError):
             u,d = u'q',u'a'
-        Misc.bat_l = Bat(action_keys=(u,d),speed=lspeed)
+        Misc.bat_l = Bat(self.rc_dic, action_keys=(u,d),speed=lspeed)
         
         if ONEPLAYER:
             Misc.bat_l.set_position((-20,220))
         else:
             Misc.bat_l.set_position((24,220))
-        Misc.ball = Ball()# now the computer player can check the ball
-        Misc.actives.add(Misc.ball)
+        Misc.ball = Ball(self.rc_dic)# now the computer player can check the ball
+        self.actives.add(Misc.ball)
         if PCPLAYER and not ONEPLAYER:#we play against the pc
-            self.PCplayer = PcPlayer()
+            self.PCplayer = PcPlayer(self.rc_dic)
         
-        Misc.actives.add([Misc.bat_r,Misc.bat_l])
-        r = Misc.actives.draw(Img.screen)
+        self.actives.add([Misc.bat_r,Misc.bat_l])
+        r = self.actives.draw(Img.screen)
         pygame.display.update(r)
-            
+
     def _draw_field(self):
         Img.screen.fill((0,0,0))
         Img.backgr.fill((0,0,0))
@@ -500,13 +570,16 @@ class Activity:
                           (398,16),\
                           (398,484),\
                           4)
+        txt = _("Hit the Escape key to stop.")
+        s = utils.char2surf(txt, 18, GREEN, bold=True)
+        Img.screen.blit(s, (50, 550))
                           
     def _splash_controls(self):
         Img.screen.fill((0,0,0))
         txt = _("Use these keys on your keyboard to control the bat.")
         txtlist = utils.txtfmt([txt],36)
-        s1,spam = utils.font2surf(txtlist[0],18,GREEN, bold=True)
-        s2,spam = utils.font2surf(txtlist[1],18,GREEN, bold=True)
+        s1,spam = utils.text2surf(txtlist[0],18,GREEN, bold=True)
+        s2,spam = utils.text2surf(txtlist[1],18,GREEN, bold=True)
         Img.screen.blit(s1,(100,200))
         Img.screen.blit(s2,(100,240))
         pygame.display.update()
@@ -518,96 +591,72 @@ class Activity:
         #surf.blit(utils.load_image(os.path.join(self.my_datadir,'bat.png')),(26,120))
         surf.blit(utils.load_image(os.path.join(self.my_datadir,'arrow_down.png')),(4,240))
         surf_r = surf.convert()# copy for the right side
-        print ONEPLAYER, PCPLAYER
+        
         if ONEPLAYER == 0 and PCPLAYER == 0:
-            surf.blit(utils.char2surf(Misc.rc_dic['left_keyup'].upper(),fsize,GREEN, bold=True),(16,70))
-            surf.blit(utils.char2surf(Misc.rc_dic['left_keydown'].upper(),fsize,GREEN, bold=True),(16,190))
-        surf_r.blit(utils.char2surf(Misc.rc_dic['right_keyup'].upper(),fsize,GREEN, bold=True),(16,70))
-        surf_r.blit(utils.char2surf(Misc.rc_dic['right_keydown'].upper(),fsize,GREEN, bold=True),(16,190))
+            surf.blit(utils.char2surf(self.rc_dic['left_keyup'].upper(),fsize,GREEN, bold=True),(16,70))
+            surf.blit(utils.char2surf(self.rc_dic['left_keydown'].upper(),fsize,GREEN, bold=True),(16,190))
+        surf_r.blit(utils.char2surf(self.rc_dic['right_keyup'].upper(),fsize,GREEN, bold=True),(16,70))
+        surf_r.blit(utils.char2surf(self.rc_dic['right_keydown'].upper(),fsize,GREEN, bold=True),(16,190))
         rects.append(Img.screen.blit(surf,(40,100)))
         rects.append(Img.screen.blit(surf_r,(700,100)))
         pygame.display.update(rects)
         pygame.time.wait(4000)
         self.skipssplash = 1
 
-    def _get_choice(self):
-        """Display the three choices of game play.
-        This will put the menu items in the actives group which then will be updated
-        in the game loop. When the users picks one the result will be handled by
-        the restart method."""
-        self.choice = None # will be set in loop
-        positions = [(130,70),(130,220),(130,370)]
-        images = ('single.jpg','multi_person.jpg','multi_pc.jpg')
-        head = _("Choose the game to play:")
-        s = utils.char2surf(head,32,GREEN, bold=True)
-        pygame.display.update(Img.screen.blit(s,(80,4)))
-        for pos,img,data in map(None,positions,images,('1','2','3')):
-            img = os.path.join(self.my_datadir,img)
-            obj = SPSpriteUtils.SPButton(utils.load_image(img),pos,data)
-            Misc.actives.add(obj) 
-        clock = pygame.time.Clock()
-        self.stop_choiceloop = 0
-        while not self.stop_choiceloop:
-            pygame.event.pump()
-            self.loop(pygame.event.get())
-            clock.tick(30)
-        # The loop is stopped by setting stop_choiceloop to True in loop
-        for obj in Misc.actives.get_sprites():
-            obj.erase_sprite()
-        Misc.actives.empty()
-        
-    def restart(self,v):
+    def restart(self):
         """Used to restart the game when there's a goal.
         This is also used to set the global vars when ending the first level(menu choices)"""
         global ONEPLAYER,PCPLAYER
-        self.logger.debug("restart called with %s" % v)
+        self.logger.debug("restart called" )
         
-        obj,val = v[0][0],v[0][1]
-        if val == -1:#scored
-            Misc.actives.empty()
+        val = self.menuchoice
+        if val == -2:#scored
+            self.actives.empty()
             self.next_exercise() 
-        # Handle the vals from the first level
+        # Handle the vals from the pre_level
         else:
             if val == '2':# 1 is the default so we don't test it
                 ONEPLAYER = 0
             elif val == '3':
                 ONEPLAYER = 0
                 PCPLAYER = 1
-            Misc.actives.empty()    
+            self.actives.empty()    
             #self.SPG.tellcore_level_end()
-        
-    def get_score(self,timespend):
-        """Mandatory method.
-        @timespend is the time spend inside the level as it's calculated
-        by the core.
-        returns the score value for the past level.
-        return None if no score value is used"""
-        m,s = timespend.split(':')
-        seconds = int(m)*60 + int(s)
-        
+    
     def loop(self,events):
         """Mandatory method.
         This is the main eventloop called by the core 30 times a minute."""
-        item,self.stop,Misc.score = None, 0,0
+        item = None
         if PCPLAYER:
-            events = self.PCplayer.play(events)# let the computer make his move. 
-            #This will add an event to pygame events. Just like a real player :-)
+            # Disabled the pcplayer, see def pre_level
+            self.pcplayer_wait += 1
+            if self.pcplayer_wait > 10:
+                self.pcplayer_wait = 0
+                events = self.PCplayer.play(events)# let the computer make his move. 
+                #It will add an event to pygame events. Just like a real player :-)
+            
         Misc.events = []#This is a hack to be able to use keydown AND keyup with
                         #CPSprite stuff
         for event in events:
+            
             if event.type == KEYDOWN or \
                     event.type == KEYUP or\
                     event.type == MOUSEBUTTONDOWN:
-                item = event
                 Misc.events.append(event)
-        
-        v = Misc.actives.refresh(item)# This will return -1 when there's a score
-        # The menu objects from the first level will return strings ('1','2' or '3')
-        if v:
-            if not self.stop_choiceloop:
-                self.stop_choiceloop = 1
-                self.restart(v)
+                item = event
+        result = self.actives.refresh(item)# This will return -2 when there's a score
+                    # The menu objects from the pre_level will return strings ('1','2' or '3')
+        if result:
+            self.menuchoice = result[0][1]
+            if self.pre_level_flag and result[0][1] != -2:
+                self.restart()
+                self.pre_level_flag = False
+                for obj in self.actives.get_sprites():
+                    obj.erase_sprite()
+                    self.actives.empty()
+                self.SPG.tellcore_pre_level_end()
             else:
-                self.restart(v)
+                self.restart()
+        
         return 
         
