@@ -486,7 +486,10 @@ class Engine:
             p = os.path.join(self.CPdatadir,'thumbs.png')
         self.good_image = SPSprite(load_image(p))
         
-        self.tryagain_image = SPSprite(load_image(os.path.join(self.my_datadir,'tryagain_%s.png' % self.lang)))
+        p = os.path.join(self.my_datadir,'tryagain_%s.png' % self.lang)
+        if not os.path.exists(p):
+            p = os.path.join(self.my_datadir,'tryagain_en.png')
+        self.tryagain_image = SPSprite(load_image(p))
                 
         iconA=load_image(os.path.join(self.my_datadir,'a.png'))
         iconB=load_image(os.path.join(self.my_datadir,'b.png'))
@@ -554,14 +557,17 @@ class Engine:
             name = 'picture'
         else:
             name = self.quiz
-        if self.lang == 'en':
-            p = os.path.join(self.SPG.get_libdir_path(),'SPData', 'themes',\
-                                        self.theme,'menuicons', \
-                                    'quiz_%s.icon.png' % name)
-        else:
-            p = os.path.join(self.SPG.get_libdir_path(),'SPData', 'themes',\
-                                        self.theme,'menuicons', self.lang, \
-                                    'quiz_%s.icon.png' % name)
+        # if self.lang == 'en':
+        #     p = os.path.join(self.SPG.get_libdir_path(),'SPData', 'themes',\
+        #                                 self.theme,'menuicons', \
+        #                             'quiz_%s.icon.png' % name)
+        # else:
+        #     p = os.path.join(self.SPG.get_libdir_path(),'SPData', 'themes',\
+        #                                 self.theme,'menuicons', self.lang, \
+        #                             'quiz_%s.icon.png' % name)
+        p = os.path.join(self.SPG.get_libdir_path(), 'SPData', 'themes',
+                                                self.theme,'menuicons',
+                                             'quiz_%s.icon.png' % name)
         self.logger.debug("loading logo %s" % p)
         try:
             self.logo_sprite = SPSprite(load_image(p))
@@ -832,8 +838,7 @@ class Engine:
             self._notify_obs(self.maxresult)
     
     def _next_question(self):
-        # This uses pygame font rendering iso pango like the rest of this app.
-        # The bigger pango fonts are not so nice.
+
         # There's a chance that these fonts are not rendered properly in non-western
         # languages.
         if self.quiz == 'math':
